@@ -15,36 +15,27 @@
 #include <QtQml>
 #include <QtWebEngineQuick>
 
+#include <KAboutData>
+#include <KCrash>
 #include <KDBusService>
 #include <KLocalizedContext>
 #include <KLocalizedString>
 #include <KWindowSystem>
 
 #include <csignal>
-#include <ranges>
 
-#include "adblockfilterlistsmanager.h"
-#include "adblockfilterlistsmodel.h"
-#include "adblockurlinterceptor.h"
 #include "angelfishsettings.h"
-#include "angelfishwebprofile.h"
-#include "bookmarkshistorymodel.h"
 #include "browsermanager.h"
-#include "domdistiller.h"
-#include "downloadsmodel.h"
+#include "version.h"
 #include "iconimageprovider.h"
 #include "tabsmodel.h"
-#include "urlobserver.h"
-#include "urlutils.h"
-#include "useragent.h"
-#include "version.h"
-#include "webappcreator.h"
-#include "webappmanagermodel.h"
 
 namespace ranges = std::ranges;
 
 constexpr auto APPLICATION_ID = "org.kde.angelfish";
 
+using namespace Qt::StringLiterals;
+
 Q_DECL_EXPORT int main(int argc, char *argv[])
 {
     // set default style and icon theme
@@ -57,7 +48,7 @@ Q_DECL_EXPORT int main(int argc, char *argv[])
 
     // Setup QtWebEngine
     qputenv("QTWEBENGINE_DIALOG_SET", "QtQuickControls2");
-    QString chromiumFlags;
+    QString chromiumFlags = qEnvironmentVariable("QTWEBENGINE_CHROMIUM_FLAGS");
     if (AngelfishSettings::self()->webSmoothScrollingEnabled()) {
         chromiumFlags.append(QStringLiteral(" --enable-smooth-scrolling"));
     }
@@ -87,6 +78,25 @@ Q_DECL_EXPORT int main(int argc, char *argv[])
     // QML loading
     QQmlApplicationEngine engine;
 
+    // Define your about data
+    KAboutData aboutData(
+        QStringLiteral("angelfish"),
+        i18n("Angelfish"),
+        QStringLiteral(ANGELFISH_VERSION_STRING),
+        i18n("Web browser for Plasma Mobile"),
+        KAboutLicense::GPL_V3,
+        i18n("© 2015-2024 KDE Community")
+    );
+
+    aboutData.addAuthor(i18n("Jonah Brüchert"), i18n("Maintainer"), QStringLiteral("jbb@kaidan.im"));
+    aboutData.setTranslator(i18nc("NAME OF TRANSLATORS", "Your names"), i18nc("EMAIL OF TRANSLATORS", "Your emails"));
+    aboutData.setOrganizationDomain("kde.org");
+    aboutData.setBugAddress("https://bugs.kde.org/describecomponents.cgi?product=angelfish");
+    KAboutData::setApplicationData(aboutData);
+
+    // Crash Handling
+    KCrash::initialize();
+
     // Open links in the already running window when e.g clicked on in another application.
     KDBusService service(KDBusService::Unique, &app);
     QObject::connect(&service, &KDBusService::activateRequested, &app, [&parser, &engine](const QStringList &arguments) {
@@ -120,9 +130,6 @@ Q_DECL_EXPORT int main(int argc, char *argv[])
         KWindowSystem::activateWindow(webbrowserWindow);
     });
 
-    // register as early possible so it has time to load, constructor doesn't block
-    qmlRegisterSingletonInstance<AdblockUrlInterceptor>(APPLICATION_ID, 1, 0, "AdblockUrlInterceptor", &AdblockUrlInterceptor::instance());
-
     engine.rootContext()->setContextObject(new KLocalizedContext(&engine));
 
     engine.addImageProvider(IconImageProvider::providerId(), new IconImageProvider());
@@ -136,36 +143,6 @@ Q_DECL_EXPORT int main(int argc, char *argv[])
         BrowserManager::instance()->setInitialUrl(initialUrl);
     }
 
-    // Exported types
-    qmlRegisterType<BookmarksHistoryModel>(APPLICATION_ID, 1, 0, "BookmarksHistoryModel");
-    qmlRegisterType<UrlObserver>(APPLICATION_ID, 1, 0, "UrlObserver");
-    qmlRegisterType<UserAgent>(APPLICATION_ID, 1, 0, "UserAgentGenerator");
-    qmlRegisterType<TabsModel>(APPLICATION_ID, 1, 0, "TabsModel");
-    qmlRegisterType<AngelfishWebProfile>(APPLICATION_ID, 1, 0, "AngelfishWebProfile");
-    qmlRegisterSingletonInstance<AngelfishSettings>(APPLICATION_ID, 1, 0, "Settings", AngelfishSettings::self());
-    qmlRegisterType<AdblockFilterListsModel>(APPLICATION_ID, 1, 0, "AdblockFilterListsModel");
-    qmlRegisterType<DownloadsModel>(APPLICATION_ID, 1, 0, "DownloadsModel");
-    qmlRegisterType<WebAppManagerModel>(APPLICATION_ID, 1, 0, "WebAppManagerModel");
-    qmlRegisterType<WebAppCreator>(APPLICATION_ID, 1, 0, "WebAppCreator");
-    qmlRegisterAnonymousType<QWebEngineUrlRequestInterceptor>(APPLICATION_ID, 1);
-
-    // Dom Distiller
-    qmlRegisterSingletonType<DomDistiller>(APPLICATION_ID, 1, 0, "DomDistiller", [](QQmlEngine *, QJSEngine *) -> QObject * {
-        return new DomDistiller();
-    });
-
-    // URL utils
-    qmlRegisterSingletonType<UrlUtils>(APPLICATION_ID, 1, 0, "UrlUtils", [](QQmlEngine *, QJSEngine *) -> QObject * {
-        return new UrlUtils();
-    });
-
-    // Browser Manager
-    qmlRegisterSingletonType<BrowserManager>(APPLICATION_ID, 1, 0, "BrowserManager", [](QQmlEngine *, QJSEngine *) -> QObject * {
-        return BrowserManager::instance();
-    });
-
-    Q_INIT_RESOURCE(resources_angelfish_generated);
-
     QObject::connect(QApplication::instance(), &QCoreApplication::aboutToQuit, QApplication::instance(), [] {
         AngelfishSettings::self()->save();
     });
@@ -194,39 +171,14 @@ Q_DECL_EXPORT int main(int argc, char *argv[])
 
     // Load QML
 
-    const QUrl url(SettingsHelper::isMobile()
-                   ? QStringLiteral("qrc:/mobile.qml")
-                   : QStringLiteral("qrc:/desktop.qml"));
-    QObject::connect(
-        &engine,
-        &QQmlApplicationEngine::objectCreated,
-        &app,
-        [url](QObject* obj, const QUrl& objUrl) {
-            if ((obj == nullptr) && url == objUrl) {
-                QCoreApplication::exit(-1);
-            }
-        },
-        Qt::QueuedConnection);
-    engine.load(url);
+    const QString url(SettingsHelper::isMobile() ? u"Mobile"_s : u"Desktop"_s);
+
+    engine.loadFromModule("org.kde.angelfish"_L1, url);
 
     // Error handling
     if (engine.rootObjects().isEmpty()) {
         return -1;
     }
 
-    const auto window = qobject_cast<QQuickWindow *>(engine.rootObjects().constFirst());
-    QObject::connect(window, &QQuickWindow::widthChanged, AngelfishSettings::self(), [window] {
-        AngelfishSettings::setWindowWidth(window->width());
-    });
-    QObject::connect(window, &QQuickWindow::heightChanged, AngelfishSettings::self(), [window] {
-        AngelfishSettings::setWindowHeight(window->height());
-    });
-    QObject::connect(window, &QQuickWindow::xChanged, AngelfishSettings::self(), [window] {
-        AngelfishSettings::setWindowX(window->x());
-    });
-    QObject::connect(window, &QQuickWindow::yChanged, AngelfishSettings::self(), [window] {
-        AngelfishSettings::setWindowY(window->y());
-    });
-
     return app.exec();
 }
