@@ -6,18 +6,19 @@
 
 #include <QAbstractListModel>
 
-#include <memory>
+#include <qqmlregistration.h>
 
 class WebAppManager;
 
 class WebAppManagerModel : public QAbstractListModel
 {
     Q_OBJECT
+    QML_ELEMENT
 
     enum Role {
         NameRole,
         IconRole,
-        UrlRole
+        UrlRole,
     };
 
 public:
